diff -urN u-boot/board/kb9202/kb9202.c u-boot.new/board/kb9202/kb9202.c
--- u-boot/board/kb9202/kb9202.c	2006-04-05 15:08:49.000000000 -0700
+++ u-boot.new/board/kb9202/kb9202.c	2006-10-03 13:50:52.000000000 -0700
@@ -31,6 +31,8 @@
 #include <at91rm9200_net.h>
 #include <lxt971a.h>
 
+extern int eth_init (bd_t * bd);
+
 DECLARE_GLOBAL_DATA_PTR;
 
 /*
@@ -64,6 +66,19 @@
 	return 0;
 }
 
+int board_late_init (void)
+{
+	/* make sure MAC is set */
+#ifdef CONFIG_DRIVER_ETHER
+#if (CONFIG_COMMANDS & CFG_CMD_NET)
+	if (getenv ("ethaddr")) {
+		return (eth_init(gd->bd));
+	}
+#endif
+#endif
+	return 0;
+}
+
 #ifdef CONFIG_DRIVER_ETHER
 #if (CONFIG_COMMANDS & CFG_CMD_NET)
 
diff -urN u-boot/include/configs/kb9202.h u-boot.new/include/configs/kb9202.h
--- u-boot/include/configs/kb9202.h	2005-10-05 16:23:26.000000000 -0700
+++ u-boot.new/include/configs/kb9202.h	2006-10-03 13:35:25.000000000 -0700
@@ -38,9 +38,10 @@
 #define CONFIG_ARM920T		1	/* This is an ARM920T Core	*/
 #define CONFIG_AT91RM9200	1	/* It's an Atmel AT91RM9200 SoC	*/
 /* Only define one of the following, based on board type		*/
-/* #define	CONFIG_KB9200		1	 KwikByte KB9202 board	*/
-/* #define	CONFIG_KB9201		1	 KwikByte KB9202 board	*/
-#define	CONFIG_KB9202		1	/* KwikByte KB9202 board	*/
+/* #define	CONFIG_KB9200		1	 KwikByte KB9200 board	*/
+/* #define	CONFIG_KB9201		1	 KwikByte KB9201 board	*/
+/* #define	CONFIG_KB9202		1	 KwikByte KB9202 board	*/
+#define CONFIG_KB9202B		1	/* KwikByte KB9202B board	*/
 
 #define	CONFIG_KB920x		1	/* Any KB920x board		*/
 #undef  CONFIG_USE_IRQ			/* we don't need IRQ/FIQ stuff	*/
@@ -54,10 +55,17 @@
 
 #define	CFG_LONGHELP
 
+#define	BOARD_LATE_INIT
+
+#ifdef CONFIG_KB9202B
+#define	CONFIG_BOOTARGS	"console=ttyS0,115200 noinitrd root=/dev/mtdblock0 rootfstype=jffs2 mem=64M"
+#define	CONFIG_BOOTCOMMAND	"bootm 0x10000000"
+#endif
+
 /*
  * Size of malloc() pool
  */
-#define CFG_MALLOC_LEN	(CFG_ENV_SIZE + 128*1024)
+#define CFG_MALLOC_LEN	(128*1024)
 #define CFG_GBL_DATA_SIZE	128	/* size in bytes reserved for initial data */
 
 #define CONFIG_BAUDRATE 115200
@@ -75,14 +83,16 @@
 
 #undef	CONFIG_MODEM_SUPPORT		/* disable modem initialization stuff */
 
-#define CONFIG_BOOTDELAY	3
+#define CONFIG_BOOTDELAY	1
 #define CONFIG_ENV_OVERWRITE	1
 
 #define CONFIG_COMMANDS		\
 		       ((CONFIG_CMD_DFL | \
 		        CFG_CMD_I2C | \
+		        CFG_CMD_EEPROM | \
 			CFG_CMD_PING | \
-			CFG_CMD_DHCP ) & \
+			CFG_CMD_DHCP | \
+			CFG_CMD_JFFS2) & \
 		      ~(CFG_CMD_BDI | \
 			CFG_CMD_FPGA | \
 			CFG_CMD_MISC))
@@ -92,17 +102,21 @@
 
 #define CONFIG_NR_DRAM_BANKS 1
 #define PHYS_SDRAM 0x20000000
+#ifdef CONFIG_KB9202B
+#define	PHYS_SDRAM_SIZE	0x4000000  /* 64 megs */
+#else
 #define PHYS_SDRAM_SIZE 0x2000000  /* 32 megs */
+#endif
 
 #define CFG_MEMTEST_START		PHYS_SDRAM
-#define CFG_MEMTEST_END			CFG_MEMTEST_START + PHYS_SDRAM_SIZE - (512*1024)
+#define CFG_MEMTEST_END			CFG_MEMTEST_START + 0x1000000
 
 #define CONFIG_DRIVER_ETHER
 #define CONFIG_NET_RETRY_COUNT		20
 
 #define CFG_FLASH_BASE			0x10000000
 
-#ifdef CONFIG_KB9202
+#if defined(CONFIG_KB9202) || defined(CONFIG_KB9202B)
 #define PHYS_FLASH_SIZE			0x1000000
 #else
 #define PHYS_FLASH_SIZE			0x200000
@@ -115,9 +129,9 @@
 
 #define	CFG_ENV_IS_IN_EEPROM
 
-#ifdef CONFIG_KB9202
-#define CFG_ENV_OFFSET			0x3E00
-#define CFG_ENV_SIZE			0x0200
+#if defined(CONFIG_KB9202) || defined(CONFIG_KB9202B)
+#define CFG_ENV_OFFSET			0x2000
+#define CFG_ENV_SIZE			0x2000
 #else
 #define CFG_ENV_OFFSET			0x1000
 #define CFG_ENV_SIZE			0x1000

